Description Usage Arguments Value See Also
View source: R/remarketingAudiences.R
Estimate number of users added to the segment yesterday
1 | ga_remarketing_estimate(remarketingAudience)
|
remarketingAudience |
A remarketing audience object from ga_remarketing_get Takes the segment definition from a remarketing audiences and runs it against the viewId to see current estimated users The total audience size is this figure for every membershipDurationDay from yesterday |
data.frame
Other managementAPI functions: ga_accounts,
ga_adwords_list, ga_adwords,
ga_custom_vars_list,
ga_custom_vars,
ga_experiment_list,
ga_experiment,
ga_filter_list,
ga_filter_view_list,
ga_filter_view, ga_filter,
ga_goal_list, ga_goal,
ga_remarketing_get,
ga_remarketing_list,
ga_segment_list,
ga_unsampled_list,
ga_unsampled, ga_view_list,
ga_view, ga_webproperty_list,
ga_webproperty,
google_analytics_account_list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.